<template>
    <div class="el-dialog-wrapper">
        <el-dialog
            :visible.sync="pointDialog" class="position-absolute dialog-center dialog-no-header" width="840px"
            top="0" :modal="false" :destroy-on-close="true" :close-on-press-escape="false" :close-on-click-modal="false"
            :modal-append-to-body="false">
            <point-test :point="point" :type="type" @proceedTest="proceedTest" :end="endTest"></point-test>
        </el-dialog>
        <el-dialog
            :visible.sync="resultDialog" class="position-absolute dialog-center dialog-no-header" width="840px"
            top="0" :modal="false" :destroy-on-close="true" :close-on-press-escape="false" :close-on-click-modal="false"
            :modal-append-to-body="false">
            <point-result-test :point="prePoint" @nextStep="nextStep" @completeTest="completeTest" :end="endTest"></point-result-test>
        </el-dialog>
        <complete-test-dialog :visible.sync="completeDialog" :type="type"></complete-test-dialog>
    </div>
</template>

<script>
import PointTest from "@/pages/test/dialog/pointTest";
import PointResultTest from "@/pages/test/dialog/pointResultTest";
import {startPointTest, completeTest} from "@/pages/test/js/api";
import CompleteTestDialog from "@/pages/test/dialog/completeTestDialog";
export default {
    name: "testStepDialog",
    components: {CompleteTestDialog, PointResultTest, PointTest},
    props: {
        type: {
            type: String,
            default: ""
        },
        step: {
            type: [Number, String],
            default: -1
        },
        list: {
            type: Array,
            default(){
                return []
            }
        },
        end: {
            type: Boolean,
            default: false,
        }
    },
    watch: {
        step() {
            this.checkStep();
        },
        end() {
            this.checkStep();
        }
    },
    data() {
        return {
            pointDialog: false,
            resultDialog: false,
            prePoint: {},
            point: {},
            endTest: false,
            completeDialog: false,
        }
    },
    methods: {
        checkStep() {
            if(this.step != -1) {
                this.changeDialog();
            }
        },
        changeDialog() {
            this.point = this.list[this.step];
            if(this.step == 0) {
                this.pointDialog = true;
            }else if(this.end) {
                this.prePoint = this.list[this.step];
                this.endTest = true;
                this.resultDialog = true;
            } else{
                this.prePoint = this.list[this.step-1];
                this.resultDialog = true;
            }
        },
        nextStep() {
            this.resultDialog = false;
            this.pointDialog = true;
        },
        proceedTest(data) {
            this.pointDialog = false;
            startPointTest(data).then(res=>{
                let rs = res.data;
                if(rs.code == 1) {
                    console.log(rs.data);
                }
            }).catch(error=>{
                console.log(error);
            });
        },
        completeTest(data) {
            completeTest(data.experimentId).then(res=>{
                let rs = res.data;
                if(rs.code == 1) {
                    this.resultDialog = false;
                    this.completeDialog = true;
                }else {
                    this.$layer.msg("完成试验失败！");
                }
            }).catch(error=>{

            });
        }
    },
    mounted() {
        this.checkStep();
    }
}
</script>

<style scoped>

</style>